# REL12-BP06: Conduct game days regularly

## Description

Run scheduled exercises để test incident response.

## Implementation Guidance

- Schedule quarterly game days
- Simulate realistic failure scenarios
- Involve all relevant teams
- Practice incident communication
- Review and improve processes

## Risk Level

Medium - Unpracticed teams respond poorly.

## Related Best Practices

- [REL12-BP05](REL12-BP05-Chaos-Engineering.md)
- [REL09-BP05](../REL09-Failure-Data-Backup/REL09-BP05-Test-Backup-Recovery.md)
